SessionState

Enum SessionState 

#[repr(u32)]
pub enum SessionState { Established = 0, Initial = 1, NonGracefullyTerminated = 2, Reconnect = 3, CorrectlyTerminated = 4, WaitForConfirmLogon = 5, WaitForConfirmLogout = 6, WaitForFirstLogon = 7, SwitchConnection = 8, WaitForFirstHello = 9, WaitForConfirmHello = 10, WaitForConnect = 11, }
Session state enum for Engine::Session::State Provides a type-safe representation of FIX session states

Variants



Established = 0

The session is fully established



Initial = 1

The session has been created, but has not been connected yet



NonGracefullyTerminated = 2

The session has been non-gracefully terminated



Reconnect = 3

The session-initiator has detected the telecommunication link error and is trying to re-establish the link



CorrectlyTerminated = 4

The session has been correctly terminated



WaitForConfirmLogon = 5

The session has been connected as an Initiator, the first Logon message has been sent and it is waiting for the conforming Logon message



WaitForConfirmLogout = 6

Waiting for confirm logout state



WaitForFirstLogon = 7

The session has been connected as an Acceptor and is waiting for the first Logon message



SwitchConnection = 8

The session switch to the another connection (backup or primary)



WaitForFirstHello = 9

The session has been connected as an Acceptor and is waiting for the first Hello message



WaitForConfirmHello = 10

The session has been connected as an Initiator, the first FAST Hello message has been sent and it is waiting for the conforming Hello message



WaitForConnect = 11

The session-initiator is waiting for async connect to complete

Implementations



impl SessionState

pub fn from_u32(value: u32) -> Result<Self, String>

Convert from u32 to SessionState